pub fn Field(props: FieldProps) -> impl IntoViewExpand description
Required Props
- children:
Children
Optional Props
- class:
impl Into<MaybeProp<String>> - label:
impl Into<MaybeProp<String>>- The label associated with the field.
- name:
impl Into<MaybeProp<String>>- A string specifying a name for the input control. This name is submitted along with the control’s value when the form data is submitted.
- orientation:
impl Into<Signal<FieldOrientation>>- The orientation of the label relative to the field component.
- required:
impl Into<Signal<bool>>- Is this input field required