pub fn Image(props: ImageProps) -> impl IntoViewExpand description
Optional Props
- class:
impl Into<MaybeProp<String>> - src:
impl Into<MaybeProp<String>>- path to the image you want to display.
- alt:
impl Into<MaybeProp<String>>- description of the image, which isn’t mandatory but is incredibly useful for accessibility.
- width:
impl Into<MaybeProp<String>>- Image width.
- height:
impl Into<MaybeProp<String>>- Image height.
- shape:
impl Into<Signal<ImageShape>>- An image can appear square, circular, or rounded.
- block:
impl Into<Signal<bool>>- An image can take up the width of its container.
- shadow:
impl Into<Signal<bool>>- An image can appear elevated with shadow.
- fit:
impl Into<Signal<ImageFit>>- An image can set how it should be resized to fit its container.