pub fn Input(props: InputProps) -> impl IntoViewExpand description
Optional Props
- class:
impl Into<MaybeProp<String>> - id:
impl Into<MaybeProp<String>> - autofocus:
impl Into<MaybeProp<bool>> - name:
impl Into<MaybeProp<String>>- A string specifying a name for the input control. This name is submitted along with the control’s value when the form data is submitted.
- rules:
impl Into<Vec<InputRule>>- The rules to validate Field.
- value:
impl Into<Model<String>>- Set the input value.
- allow_value: [
impl Into<ArcOneCallback<String, bool>>](ArcOneCallback<String, bool>)- Check the incoming value, if it returns false, input will not be accepted.
- input_type:
impl Into<Signal<InputType>>- An input can have different text-based types based on the type of value the user will enter.
- placeholder:
impl Into<MaybeProp<String>>- Placeholder text for the input.
- on_focus:
impl Into<BoxOneCallback<ev::FocusEvent>>- Callback triggered when the input is focussed on.
- on_blur:
impl Into<BoxOneCallback<ev::FocusEvent>>- Callback triggered when the input is blurred.
- disabled:
impl Into<Signal<bool>>- Whether the input is disabled.
- readonly:
impl Into<Signal<bool>>- Whether the input is readonly.
- input_size:
impl Into<Signal<Option<i32>>>- Input size width.
- input_prefix:
InputPrefix - input_suffix:
InputSuffix - input_style:
impl Into<MaybeProp<String>> - comp_ref:
ComponentRef<InputRef> - parser: [
impl Into<OptionalProp<BoxOneCallback<String, Option<String>>>>](OptionalProp<BoxOneCallback<String, Option>>) - Modifies the user input before assigning it to the value.
- format: [
impl Into<OptionalProp<BoxOneCallback<String, String>>>](OptionalProp<BoxOneCallback<String, String>>)- Formats the value to be shown to the user.
- size:
impl Into<Signal<InputSize>>- Size of the input (changes the font size and spacing).
- autocomplete:
impl Into<MaybeProp<String>>