pub fn Link(props: LinkProps) -> impl IntoViewExpand description
Required Props
- children:
Children
Optional Props
- class:
impl Into<MaybeProp<String>> - span:
bool - inline:
impl Into<Signal<bool>>- If true, changes styling when the link is being used alongside other text content.
- href:
impl Into<Signal<String>> - disabled:
impl Into<Signal<bool>>- Whether the link is disabled.
- disabled_focusable:
impl Into<Signal<bool>>- When set, allows the link to be focusable even when it has been disabled.