pub fn NavDrawer(props: NavDrawerProps) -> impl IntoViewExpand description
Required Props
- children:
Children
Optional Props
- class:
impl Into<MaybeProp<String>> - selected_value:
impl Into<OptionModel<String>>- The value of the currently selected navItem.
- selected_category_value:
impl Into<OptionModel<String>>- Indicates a category that has a selected child Will show the category as selected if it is closed.
- open_categories:
impl Into<Model<Vec<String>>>- Controls the open categories.
- multiple:
impl Into<Signal<bool>>- Indicates if NavDrawer supports multiple open Categories at the same time.
- nav_drawer_header:
NavDrawerHeader - nav_drawer_footer:
NavDrawerFooter