SpinButton

Function SpinButton 

pub fn SpinButton<T>(props: SpinButtonProps<T>) -> impl IntoView
where T: Send + Sync + Add<Output = T> + Sub<Output = T> + PartialOrd + Bounded + Default + Clone + FromStr + ToString + 'static,
SpinButton are used to allow numerical input bounded between minimum and maximum values with buttons to increment and decrement the input value.

Note: SpinButton is a generic component, so the type must be specified. Example: <SpinButton<i32> step_page=1/>. Related issue

Required Props

  • step_page: impl Into<Signal<T>>
    • Large difference between two values. This should be greater than step and is used when users hit the Page Up or Page Down keys.

Optional Props