pub fn Switch(props: SwitchProps) -> impl IntoViewExpand description
Optional Props
- class:
impl Into<MaybeProp<String>> - id:
impl Into<MaybeProp<String>> - name:
impl Into<MaybeProp<String>>- A string specifying a name for the input control. This name is submitted along with the control’s value when the form data is submitted.
- value:
impl Into<MaybeProp<String>>- A String specifying the value of the input control.
- rules:
impl Into<Vec<SwitchRule>>- The rules to validate Field.
- checked:
impl Into<Model<bool>>- Defines the controlled checked state of the Switch.
- label:
impl Into<MaybeProp<String>>- The Switch’s label.