pub struct AvatarProps {
pub class: MaybeProp<String>,
pub src: MaybeProp<String>,
pub name: MaybeProp<String>,
pub initials: MaybeProp<String>,
pub shape: Signal<AvatarShape>,
pub size: MaybeProp<u8>,
}Expand description
Props for the Avatar component.
Optional Props
- class:
impl Into<MaybeProp<String>> - src:
impl Into<MaybeProp<String>>- The Avatar’s image.
- name:
impl Into<MaybeProp<String>>- The name of the person or entity represented by this Avatar.
- initials:
impl Into<MaybeProp<String>>- Custom initials.
- shape:
impl Into<Signal<AvatarShape>>- The avatar can have a circular or square shape.
- size:
impl Into<MaybeProp<u8>>- Size of the avatar in pixels.
Fields
class: MaybeProp<String>src: MaybeProp<String>The Avatar’s image.
name: MaybeProp<String>The name of the person or entity represented by this Avatar.
initials: MaybeProp<String>Custom initials.
shape: Signal<AvatarShape>The avatar can have a circular or square shape.
size: MaybeProp<u8>Size of the avatar in pixels.
Implementations
Sourceimpl AvatarProps
impl AvatarProps
Sourcepub fn builder() -> AvatarPropsBuilder<((), (), (), (), (), ())>
pub fn builder() -> AvatarPropsBuilder<((), (), (), (), (), ())>
Create a builder for building AvatarProps.
On the builder, call .class(...)(optional), .src(...)(optional), .name(...)(optional), .initials(...)(optional), .shape(...)(optional), .size(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of AvatarProps.