pub struct PersonaProps {
pub class: MaybeProp<String>,
pub style: MaybeProp<String>,
pub name: MaybeProp<String>,
pub size: Signal<PersonaSize>,
pub text_alignment: Signal<PersonaTextAlignment>,
pub text_position: Signal<PersonaTextPosition>,
pub avatar_src: MaybeProp<String>,
pub persona_primary_text: Option<PersonaPrimaryText>,
pub persona_secondary_text: Option<PersonaSecondaryText>,
pub persona_tertiary_text: Option<PersonaTertiaryText>,
pub persona_quaternary_text: Option<PersonaQuaternaryText>,
}Expand description
Props for the Persona component.
Optional Props
- class:
impl Into<MaybeProp<String>> - style:
impl Into<MaybeProp<String>> - name:
impl Into<MaybeProp<String>>- The name of the person or entity represented by the Persona. When primary_text is not provided, this will be used as the default value for primaryText.
- size:
impl Into<Signal<PersonaSize>>- The size of a Persona and its text.
- text_alignment:
impl Into<Signal<PersonaTextAlignment>>- The vertical alignment of the text relative to the avatar.
- text_position:
impl Into<Signal<PersonaTextPosition>>- The position of the text relative to the avatar.
- avatar_src:
impl Into<MaybeProp<String>> - persona_primary_text:
PersonaPrimaryText- The first line of text in the Persona, larger than the rest of the lines.
- persona_secondary_text:
PersonaSecondaryText- The second line of text in the Persona.
- persona_tertiary_text:
PersonaTertiaryText- The third line of text in the Persona.
- persona_quaternary_text:
PersonaQuaternaryText- The fourth line of text in the Persona.
Fields
class: MaybeProp<String>style: MaybeProp<String>name: MaybeProp<String>The name of the person or entity represented by the Persona. When primary_text is not provided, this will be used as the default value for primaryText.
size: Signal<PersonaSize>The size of a Persona and its text.
text_alignment: Signal<PersonaTextAlignment>The vertical alignment of the text relative to the avatar.
text_position: Signal<PersonaTextPosition>The position of the text relative to the avatar.
avatar_src: MaybeProp<String>persona_primary_text: Option<PersonaPrimaryText>The first line of text in the Persona, larger than the rest of the lines.
persona_secondary_text: Option<PersonaSecondaryText>The second line of text in the Persona.
persona_tertiary_text: Option<PersonaTertiaryText>The third line of text in the Persona.
persona_quaternary_text: Option<PersonaQuaternaryText>The fourth line of text in the Persona.
Implementations
Sourceimpl PersonaProps
impl PersonaProps
Sourcepub fn builder() -> PersonaPropsBuilder<((), (), (), (), (), (), (), (), (), (), ())>
pub fn builder() -> PersonaPropsBuilder<((), (), (), (), (), (), (), (), (), (), ())>
Create a builder for building PersonaProps.
On the builder, call .class(...)(optional), .style(...)(optional), .name(...)(optional), .size(...)(optional), .text_alignment(...)(optional), .text_position(...)(optional), .avatar_src(...)(optional), .persona_primary_text(...)(optional), .persona_secondary_text(...)(optional), .persona_tertiary_text(...)(optional), .persona_quaternary_text(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of PersonaProps.