pub fn MessageBar(props: MessageBarProps) -> impl IntoViewExpand description
Communicates important information about the state of the entire application or surface. For example, the status of a page, panel, dialog or card. The information shouldn’t require someone to take immediate action, but should persist until the user performs one of the required actions.
Required Props
- children:
Children
Optional Props
- class:
impl Into<MaybeProp<String>> - layout:
impl Into<MessageBarLayout> - intent:
impl Into<Signal<MessageBarIntent>>- Default designs announcement presets.